###################################################
### chunk number 1: 
###################################################
# In a verbatim environment, more than 98 will go over the edge
options(width=90,digits=4)


###################################################
### chunk number 2: setup
###################################################
library(NestedCohort)
data(zinc)


###################################################
### chunk number 3: SeeVariables
###################################################
str(zinc)


###################################################
### chunk number 4: KaplanMeier
###################################################
mod <- nested.km(survfitformula="Surv(futime01,ec01==1)~znquartiles",
                       samplingmod="ec01*basehist",exposureofinterest="Q4",data=zinc)


###################################################
### chunk number 5: SummaryKaplanMeier
###################################################
summary(mod)


###################################################
### chunk number 6: PlotKM
###################################################
plot(mod,ymin=.6,xlab="time",ylab="survival",main="Survival by Quartile of Zinc",
     legend.text=c("Q1","Q2","Q3","Q4"),lty=1:4,legend.pos=c(2000,.7))


###################################################
### chunk number 7: HazardRatios
###################################################
coxmod <- nested.coxph(coxformula="Surv(futime01,ec01==1)~sex+agepill+basehist+anyhist+zncent",samplingmod="ec01*basehist",data=zinc)
summary(coxmod) 


###################################################
### chunk number 8: StdSurv
###################################################
mod<-nested.stdsurv(outcome="Surv(futime01,ec01==1)",exposures="znquartiles",
                      confounders="sex+agestr+basehist+anyhist",
                      samplingmod="ec01*basehist",exposureofinterest="Q4",data=zinc)


###################################################
### chunk number 9: PlotStdSurv
###################################################
mod<-nested.stdsurv(outcome="Surv(futime01,ec01==1)",exposures="znquartiles",
                      confounders="sex+agestr+basehist+anyhist",
                      samplingmod="ec01*basehist",exposureofinterest="Q4",plot=T,
                        main="Time to Esophageal Cancer by Quartiles of Zinc",data=zinc)


###################################################
### chunk number 10: JointHazardRatios
###################################################
coxmod <- nested.coxph("Surv(futime01,ec01==1)~sex+agepill+basehist+anyhist+zncent+cacent",samplingmod="ec01*basehist",data=zinc)
summary(coxmod) 


###################################################
### chunk number 11: JointStdSurv
###################################################
zinc$caquartiles <- cut(zinc$cacent,breaks=quantile(zinc$cacent,seq(0,1,1/4),na.rm=T),include.lowest=T,labels=paste("Q",1:4,sep=""))
mod <- nested.stdsurv(outcome="Surv(futime01,ec01==1)",exposures="znquartiles+caquartiles",
                      confounders="sex+agestr+basehist+anyhist",
                      samplingmod="ec01*basehist",exposureofinterest="Q4,Q4",data=zinc)


